@@ -13,11 +13,10 @@ import traceback
 from pwbus.commons.logging import log_exit
 from pwbus.engines.engine_manager import EngineManager
 
-# pwbus
-#
 
+def main():
+    argv = sys.argv[1:]
 
-def main(argv):
     channel = None
     engine = None
     command = None
@@ -60,4 +59,4 @@ def main(argv):
 # __main__
 #
 if __name__ == "__main__":
-    pwbus(sys.argv[1:])
+    main()
